netapp_ontap.models.nas_application_components API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.nas_application_components`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class NasApplicationComponentsSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the NasApplicationComponents object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `export_policy: NasApplicationComponentsExportPolicy GET POST`

    The export_policy field of the nas_application_components.

  `flexcache: NasApplicationComponentsFlexcache GET POST`

    The flexcache field of the nas_application_components.

  `name: str GET POST PATCH`

    The name of the application component.

  `qos: NasApplicationComponentsQos GET POST`

    The qos field of the nas_application_components.

  `scale_out: bool GET POST`

    Denotes a Flexgroup.

  `share_count: Size GET POST`

    The number of shares in the application component.

  `snaplock: NasApplicationComponentsSnaplock GET POST`

    The snaplock field of the nas_application_components.

  `snapshot_locking_enabled: bool GET POST`

    Indicates whether Snapshot copy locking is enabled on the volume.

  `storage_service: NasApplicationComponentsStorageService GET POST PATCH`

    The storage_service field of the nas_application_components.

  `tiering: NasApplicationComponentsTiering GET POST PATCH`

    application-components.tiering

  `total_size: Size GET POST PATCH`

    The total size of the application component, split across the member shares. Usage: {<integer>[KB|MB|GB|TB|PB]}